;; Generated package description from setup.el  -*- no-byte-compile: t -*-
(define-package "setup" "1.4.0.0.20240413.75454" "Helpful Configuration Macro" '((emacs "26.1")) :commit "858ea70760426a9e1fa1ce1f21fb8f8d62bd1803" :authors '(("Philip Kaludercic" . "philipk@posteo.net")) :maintainer '("Philip Kaludercic" . "~pkal/public-inbox@lists.sr.ht") :keywords '("lisp" "local") :url "https://git.sr.ht/~pkal/setup")
